@@ -2,8 +2,8 @@
 
 # Script to call all PyPion classes to plot 2d + 3d Silo data.
 
-from Plotting_Classes import Plotting2d, Plotting3d
-from argparse_command import InputValues
+from .Plotting_Classes import Plotting2d, Plotting3d
+from .argparse_command import InputValues
 #-------------------------------
 import matplotlib
 # Using this to stop matplotlib from using a $DISPLAY environment variable.
